# Vector field functions

## Initialization

```{eval-rst}
.. autoapisummary::

    deepali.core.flow.affine_flow
    deepali.core.flow.compose_flows
    deepali.core.flow.zeros_flow

```

## Normalization

```{eval-rst}
.. autoapisummary::

    deepali.core.flow.normalize_flow
    deepali.core.flow.denormalize_flow

```

## Sampling

```{eval-rst}
.. autoapisummary::

    deepali.core.flow.sample_flow

```

## Warping

```{eval-rst}
.. autoapisummary::

    deepali.core.flow.warp_grid
    deepali.core.flow.warp_points
    deepali.core.flow.warp_image

```

## Miscellaneous

```{eval-rst}
.. autoapisummary::

    
    deepali.core.flow.curl
    deepali.core.flow.expv
    deepali.core.flow.jacobian_det

```
